summaryrefslogtreecommitdiffstats
path: root/content/public/browser/resource_request_info.h
diff options
context:
space:
mode:
authorjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-12-20 23:17:16 +0000
committerjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-12-20 23:17:16 +0000
commitf3add92d73df86fa62bf727b0016e0c62149b326 (patch)
treef2d0012dd68061378276814f1c5108e010bda7a5 /content/public/browser/resource_request_info.h
parent13c3497e0bf749e2bf9bb4e0112bf7b1bab63933 (diff)
downloadchromium_src-f3add92d73df86fa62bf727b0016e0c62149b326.zip
chromium_src-f3add92d73df86fa62bf727b0016e0c62149b326.tar.gz
chromium_src-f3add92d73df86fa62bf727b0016e0c62149b326.tar.bz2
A bunch of work to transition from render_view_id to render_frame_id.
-remove ResourceRequestInfo::GetRenderViewForRequest -reduce usage of GetAssociatedRenderView and add GetAssociatedRenderFrame which will replace it -move the cookie jar from RenderView to RenderFrame -switch most of the usages of RenderView to RenderFrame in WebPluginImpl BUG=304341 R=boliu@chromium.org, nasko@chromium.org Review URL: https://codereview.chromium.org/114573003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@242200 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/public/browser/resource_request_info.h')
-rw-r--r--content/public/browser/resource_request_info.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/content/public/browser/resource_request_info.h b/content/public/browser/resource_request_info.h
index 1c191ab..d564082 100644
--- a/content/public/browser/resource_request_info.h
+++ b/content/public/browser/resource_request_info.h
@@ -37,14 +37,14 @@ class ResourceRequestInfo {
int render_view_id,
bool is_async);
// Returns the associated RenderView for a given process. Returns false, if
// there is no associated RenderView. This method does not rely on the
// request being allocated by the ResourceDispatcherHost, but works for all
- // URLRequests that are associated with a RenderView.
- CONTENT_EXPORT static bool GetRenderViewForRequest(
+ // URLRequests that are associated with a RenderFrame.
+ CONTENT_EXPORT static bool GetRenderFrameForRequest(
const net::URLRequest* request,
int* render_process_id,
- int* render_view_id);
+ int* render_frame_id);
// Returns the associated ResourceContext.
virtual ResourceContext* GetContext() const = 0;
@@ -100,9 +100,14 @@ class ResourceRequestInfo {
virtual bool WasIgnoredByHandler() const = 0;
// Returns false if there is NOT an associated render view.
+ // TODO(jam): remove this. http://crbug.com/304341
virtual bool GetAssociatedRenderView(int* render_process_id,
int* render_view_id) const = 0;
+ // Returns false if there is NOT an associated render frame.
+ virtual bool GetAssociatedRenderFrame(int* render_process_id,
+ int* render_frame_id) const = 0;
+
// Returns true if this is associated with an asynchronous request.
virtual bool IsAsync() const = 0;
@@ -37,14 +37,14 @@ class ResourceRequestInfo {
int render_view_id,
bool is_async);
- // Returns the associated RenderView for a given process. Returns false, if
- // there is no associated RenderView. This method does not rely on the
+ // Returns the associated RenderFrame for a given process. Returns false, if
+ // there is no associated RenderFrame. This method does not rely on the
// request being allocated by the ResourceDispatcherHost, but works for all